@@ -10,8 +10,9 @@ mod types;
 pub use {
 	alter_row::ValidateError,
 	alter_table::AlterError,
-	execute::{execute, ExecuteError, Payload},
+	execute::{ExecuteError, Payload},
 	fetch::FetchError,
 	query::{JoinError, ManualError, PlanError, QueryError, SelectError},
 	recipe::*,
+	types::ComplexTableName,
 };
